@@ -13,15 +13,18 @@ has count       => 0;
 has owner       => sub {
   $_[0]->app->users->find_where({login_name => 'foo'});
 };
-has 'dom';
+has [qw(skip_qr refresh_qr dom)] => undef;
 
 sub run ($self, @args) {
   my $app = $self->app;
   getopt \@args,
-    'n|name=s'    => \(my $name    = ''),
-    'o|owner=s'   => \(my $owner   = $self->owner->{login_name}),
-    'a|aliases=s' => \(my $aliases = ''),
-    'c|chmod=s'   => \(my $chmod   = oct(700));
+    'n|name=s'    => \(my $name),
+    'o|owner=s'   => \(my $owner = $self->owner->{login_name}),
+    'a|aliases=s' => \(my $aliases),
+    'c|chmod=s'   => \(my $chmod = oct(700)),
+    's|skip=s'    => \(my $skip_qr),
+    'r|refresh=s' => \(my $refresh_qr),
+    ;
 
   # Display readable UTF-8
   # Redefine Data::Dumper::qquote() to do nothing
@@ -57,14 +60,31 @@ sub run ($self, @args) {
     say 'Domain aliases: ' . $aliases;
   }
 
+  unless (defined $skip_qr) {
+    say 'Will not skip any file.';
+  }
+  else {
+    say "Will skip files matching '$skip_qr'.";
+    $self->skip_qr($skip_qr);
+  }
+
+  unless (defined $refresh_qr) {
+    say 'Will not refresh any file.';
+  }
+  else {
+    say "Will refresh files matching '$refresh_qr'.";
+    $self->refresh_qr($refresh_qr);
+  }
+
   $self->create_dir($root)->chmod_file($root, $chmod)->create_dir("$root/$name")
     ->chmod_file("$root/$name", $chmod);
 
   # copy default static files and templates
   $self->_copy_resourses_to("$root/$name", $chmod);
 
-  # create and update records in database
-  $self->_create_domain($name, $aliases)->_create_pages()->_update_admin();
+  # create and update records in database unless refreshed
+  $self->_create_domain($name, $aliases)->_create_pages()->_update_admin()
+    unless defined $self->refresh_qr;
   return $self;
 }
 
@@ -85,7 +105,17 @@ sub _copy_resourses_to ($self, $to, $chmod) {
 }
 
 sub _copy_to ($self, $from, $f, $i, $to, $chmod) {
-  my $copy = $to . '/' . ($f =~ s/$from\///r);
+  my $skip_qr    = $self->skip_qr;
+  my $refresh_qr = $self->refresh_qr;
+  my $copy       = $to . '/' . ($f =~ s/$from\///r);
+
+  return if defined $skip_qr && $copy =~ /$skip_qr/;
+
+  if (defined $refresh_qr && $copy =~ /$refresh_qr/ && -e $copy) {
+    path($copy)
+      ->remove_tree({keep_root => 1, verbose => 1, safe => 1, error => \(my $err)});
+    _handle_remove_err($err);
+  }
   return $self->create_dir($copy)->chmod_file($copy, $chmod) if -d $f;
   if (-f $f) {
     my $parent = path($copy)->dirname;
@@ -101,6 +131,21 @@ sub _copy_to ($self, $from, $f, $i, $to, $chmod) {
   return;
 }
 
+sub _handle_remove_err($err) {
+  if ($err && @$err) {
+    for my $diag (@$err) {
+      my ($file, $message) = %$diag;
+      if ($file eq '') {
+        say "general error: $message";
+      }
+      else {
+        say "problem unlinking $file: $message";
+      }
+    }
+  }
+  return;
+}
+
 # returns the id of the created domain
 sub _create_domain ($self, $name, $aliases) {
   say 'Creating record for domain ' . $name;
@@ -196,15 +241,20 @@ sub _update_admin($self) {
 
 =head1 NAME
 
-Slovo::Command::Author::generate::novy_dom - Generate database records, files and pages for a new domain
+Slovo::Command::Author::generate::novy_dom - Generate database records, files
+and pages for a new domain
 
 =head1 SYNOPSIS
 
-    Usage: slovo [OPTIONS]
+    Usage: slovo generate novy_dom [OPTIONS]
     # Default values.
     slovo generate novy_dom -n example.com
-    # Custom values
+    # Custom values.
     slovo generate novy_dom -n test.com -o краси
+    # Do not copy templates nor css files.
+    slovo generate novy_dom -n test.com -o краси -s '.*?\.(ep|css)$'
+    # Refresh all copied templates from upgraded Slovo
+    slovo generate novy_dom -n test.com -o краси -r '.*\.ep$'
 
   Options:
     -h, --help    Show this summary of available options
@@ -215,6 +265,15 @@ Slovo::Command::Author::generate::novy_dom - Generate database records, files an
                   Defaults to "foo".
     -c, --chmod   Octal number used as permissions for folders.
                   Defaults to 0700.
+    -s, --skip    A regex. The files matching this regex will not be copied
+                  to the domain folder.
+    -r, --refresh A regex. Danger! The files matching this regex will be
+                  removed, thus allowing files from upgraded Slovo to be copied
+                  to the domain folders. This pattern is used after --skip
+                  which takes precendence.
+                  In case this option is passed, the domain will not be
+                  recreated, pages will not be recreated and the admin user
+                  will not be updated.
 
 =head1 DESCRIPTION
 
@@ -235,6 +294,16 @@ C<admin> so it can manage the domain. It will be disabled after one hour for
 security reasons. Set it's stop_date to 0 to prevent this. All
 domain owners become admins. Please keep the number of admins low.
 
+Sometimes you do not want all files to be copied and just use the common files
+provided by Slovo or you want to make your own layouts, styles etc. In these
+cases you can use the C<--skip> option.
+
+Sometimes after upgrading Slovo to a new version you may want or need to update
+the copied to your domain folder files. In this case you can use the
+C<--refresh> option. Beware that C<novy_dom> will delete all the files matching
+the provided pattern. I<It is recommended to use some version control system
+like Git for you folder C<domove> to avoid resetting your files by mistake.>
+
 =head1 ATTRIBUTES
 
 L<Slovo::Command::Author::generate::novy_dom> inherits all attributes from
