@@ -24,13 +24,12 @@ sub breadcrumb ($m, $p_alias, $path, $l, $user, $preview) {
     my ($u_SQL, @bind) = $abstr->select(
       $table, undef,
       {
-       "page_id"  => \[$page_id_SQL, $p_alias],
-       "alias"    => $cel,
-       "language" => $m->celini->language_like($l),
-       %{$m->where_with_permissions($user, $preview)},
+        "page_id"  => \[$page_id_SQL, $p_alias],
+        "alias"    => $cel,
+        "language" => $m->celini->language_like($l),
+        %{$m->where_with_permissions($user, $preview)},
 
-      }
-    );
+      });
     push @SQL,   $u_SQL;
     push @BINDS, @bind;
   }
@@ -51,39 +50,30 @@ sub where_with_permissions ($self, $user, $preview) {
       {"$table.published" => 2, "$table.permissions" => {-like => '%r_x'}},
 
       # preview of a page with elements, owned by this user
-      {
-       "$table.user_id"     => $user->{id},
-       "$table.permissions" => {-like => '_r_x%'}
-      },
+      {"$table.user_id" => $user->{id}, "$table.permissions" => {-like => '_r_x%'}},
 
       # preview of elements, which can be read and executed
       # by one of the groups to which this user belongs.
       {
-       "$table.permissions" => {-like => '____r_x%'},
-       "$table.published"   => $preview ? 1 : 2,
-       "$table.group_id"    => \[
-           "IN (SELECT group_id from user_group WHERE user_id=?)" => $user->{id}
-       ],
+        "$table.permissions" => {-like => '____r_x%'},
+        "$table.published"   => $preview ? 1 : 2,
+        "$table.group_id" =>
+          \["IN (SELECT group_id from user_group WHERE user_id=?)" => $user->{id}],
       },
-    ]
-  };
+    ]};
 }
 
-sub all_for_display_in_stranica ($self, $page, $user, $l, $preview, $opts = {})
-{
-  return $self->all(
-    {
-     where => {
-       page_id      => $page->{id},
-       "$table.pid" => 0,             #only content belonging directly to a page
-       language => $self->language_like($l),
-       %{$self->where_with_permissions($user, $preview)},
-       %{delete $opts->{where} // {}}
-              },
-     order_by => [{-desc => 'featured'}, {-asc => [qw(id sorting)]},],
-     %$opts,
-    }
-  );
+sub all_for_display_in_stranica ($self, $page, $user, $l, $preview, $opts = {}) {
+  return $self->all({
+    where => {
+      page_id      => $page->{id},
+      "$table.pid" => 0,                        #only content belonging directly to a page
+      language     => $self->language_like($l),
+      %{$self->where_with_permissions($user, $preview)}, %{delete $opts->{where} // {}}
+    },
+    order_by => [{-desc => 'featured'}, {-asc => [qw(id sorting)]},],
+    %$opts,
+  });
 }
 
 sub find_for_display ($m, $alias, $user, $l, $preview, $where = {}) {
@@ -105,11 +95,11 @@ SQL
 
   #local $m->dbx->db->dbh->{TraceLevel} = "3|SQL";
   my $_where = {
-                alias => [$alias, \[$old_alias_SQL => $alias, $alias, $alias]],
-                language => $m->language_like($l),
-                box      => {-in => [qw(главна main)]},
-                %{$m->where_with_permissions($user, $preview)}, %$where
-               };
+    alias    => [$alias, \[$old_alias_SQL => $alias, $alias, $alias]],
+    language => $m->language_like($l),
+    box      => {-in => [qw(главна main)]},
+    %{$m->where_with_permissions($user, $preview)}, %$where
+  };
   return $m->dbx->db->select($table, undef, $_where)->hash;
 }
 
@@ -122,11 +112,9 @@ sub save ($m, $id, $row) {
   eval {
     my $tx = $db->begin;
     $m->upsert_aliases($db, $id, $row->{alias});
-    $db->update($stranici_table,
-                {tstamp => $row->{tstamp}},
-                {id     => $row->{page_id}});    #parent page
-    $db->update($table, {tstamp => $row->{tstamp}}, {id => $row->{pid}})
-      ;                                          #parent
+    $db->update($stranici_table, {tstamp => $row->{tstamp}}, {id => $row->{page_id}})
+      ;    #parent page
+    $db->update($table, {tstamp => $row->{tstamp}}, {id => $row->{pid}});    #parent
     $db->update($table, $row, {id => $id});
     $tx->commit;
   } || Carp::croak("Error updating $table: $@");
